@@ -1,6 +1,8 @@
 import asyncio
+from unittest.mock import Mock, patch
+
 import pytest
-from mode.utils.mocks import Mock, patch
+
 from mode.utils.tracebacks import Traceback, format_task_stack
 
 
@@ -15,16 +17,15 @@ async def test_format_task_stack():
     async def bar():
         await baz()
 
-    @asyncio.coroutine
-    def baz():
+    async def baz():
         task = asyncio.ensure_future(xuz())
-        yield from asyncio.sleep(0.1)
+        await asyncio.sleep(0.1)
         for _ in range(100):
             assert format_task_stack(task, limit=0)
             assert format_task_stack(task, limit=-300)
             assert format_task_stack(task, limit=None)
             assert format_task_stack(task, limit=3, capture_locals=True)
-        yield from on_done.wait()
+        await on_done.wait()
 
     async def xuz():
         await xuz1()
@@ -48,9 +49,8 @@ async def test_format_task_stack():
     await asyncio.sleep(0.05)
     assert format_task_stack(task, limit=None)
 
-    @asyncio.coroutine
-    def moo():
-        yield from asyncio.sleep(0.1)
+    async def moo():
+        await asyncio.sleep(0.1)
 
     task = asyncio.ensure_future(moo())
     await asyncio.sleep(0.05)
@@ -58,17 +58,15 @@ async def test_format_task_stack():
 
 
 class test_Traceback:
-
     @pytest.fixture()
     def frame(self):
-        return Mock(name='frame')
+        return Mock(name="frame")
 
     @pytest.fixture()
     def tb(self, *, frame):
         return Traceback(frame)
 
     def test_from_coroutine__async_generator_asend(self, tb):
-
         class async_generator_asend:
             f_lineno = 303
             f_lasti = None
@@ -76,7 +74,6 @@ class test_Traceback:
         assert Traceback.from_coroutine(async_generator_asend())
 
     def test_from_coroutine__unknown(self, tb):
-
         class foo_frame:
             f_lineno = 303
             f_lasti = None
@@ -98,6 +95,6 @@ class test_Traceback:
             cr_frame = None
             cr_await = Mock()
 
-        with patch('asyncio.iscoroutine') as iscoroutine:
+        with patch("asyncio.iscoroutine") as iscoroutine:
             iscoroutine.return_value = True
             Traceback.from_coroutine(coro(), limit=10)
